@@ -1,6 +1,6 @@
 from .numerical_expression import construct_expression_tree, calculate, evaluate_expression, NumericalExpressionTree
 from .observation import ActionCall, Observation, ObservedComponent, MultiAgentObservation, MultiAgentComponent
-from .pddl_action import NumericPrecondition, Action, NumericEffect
+from .pddl_action import Action
 from .pddl_domain import Domain
 from .pddl_function import PDDLFunction
 from .pddl_object import PDDLObject, PDDLConstant
