@@ -70,4 +70,4 @@ def test_parse_ma_combined_trajectory(ma_trajectory_parser: TrajectoryParser):
     observation = ma_trajectory_parser.parse_trajectory(WOODWORKING_COMBINED_TRAJECTORY_PATH,
                                                         executing_agents=WOODWORKING_AGENT_NAMES)
     assert len(observation.components) == 4
-    print(observation.components[0].grounded_action_call)
+    print(observation.components[0].grounded_joint_action)
